git@vger.kernel.org mailing list mirror (one of many)
 help / color / mirror / code / Atom feed
From: Michael Haggerty <mhagger@alum.mit.edu>
To: Junio C Hamano <gitster@pobox.com>
Cc: "Nguyễn Thái Ngọc Duy" <pclouds@gmail.com>,
	"Stefan Beller" <sbeller@google.com>, "Jeff King" <peff@peff.net>,
	"Ævar Arnfjörð Bjarmason" <avarab@gmail.com>,
	"David Turner" <novalis@novalis.org>,
	"Brandon Williams" <bmwill@google.com>,
	git@vger.kernel.org, "Michael Haggerty" <mhagger@alum.mit.edu>
Subject: [PATCH 22/28] packed_refs_lock(): function renamed from lock_packed_refs()
Date: Thu, 15 Jun 2017 16:47:27 +0200	[thread overview]
Message-ID: <fdc991cfb05588fc93778a6ce3df197ac6c95146.1497534157.git.mhagger@alum.mit.edu> (raw)
In-Reply-To: <cover.1497534157.git.mhagger@alum.mit.edu>

Rename `lock_packed_refs()` to `packed_refs_lock()` for consistency
with how other methods are named. Also, it's about to get some
companions.

Signed-off-by: Michael Haggerty <mhagger@alum.mit.edu>
---
 refs/files-backend.c  |  4 ++--
 refs/packed-backend.c | 10 +++++-----
 refs/packed-backend.h |  2 +-
 3 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/refs/files-backend.c b/refs/files-backend.c
index 4323394a52..3fc2254e33 100644
--- a/refs/files-backend.c
+++ b/refs/files-backend.c
@@ -1084,7 +1084,7 @@ static int files_pack_refs(struct ref_store *ref_store, unsigned int flags)
 	struct ref_to_prune *refs_to_prune = NULL;
 	struct strbuf err = STRBUF_INIT;
 
-	lock_packed_refs(refs->packed_ref_store, LOCK_DIE_ON_ERROR);
+	packed_refs_lock(refs->packed_ref_store, LOCK_DIE_ON_ERROR);
 
 	iter = cache_ref_iterator_begin(get_loose_ref_cache(refs), NULL, 0);
 	while ((ok = ref_iterator_advance(iter)) == ITER_OK) {
@@ -2667,7 +2667,7 @@ static int files_initial_transaction_commit(struct ref_store *ref_store,
 		}
 	}
 
-	if (lock_packed_refs(refs->packed_ref_store, 0)) {
+	if (packed_refs_lock(refs->packed_ref_store, 0)) {
 		strbuf_addf(err, "unable to lock packed-refs file: %s",
 			    strerror(errno));
 		ret = TRANSACTION_GENERIC_ERROR;
diff --git a/refs/packed-backend.h b/refs/packed-backend.h
index 3d4057b65b..dbc00d3396 100644
--- a/refs/packed-backend.h
+++ b/refs/packed-backend.h
@@ -9,7 +9,7 @@ struct ref_store *packed_ref_store_create(const char *path,
  * hold_lock_file_for_update(). Return 0 on success. On errors, set
  * errno appropriately and return a nonzero value.
  */
-int lock_packed_refs(struct ref_store *ref_store, int flags);
+int packed_refs_lock(struct ref_store *ref_store, int flags);
 
 void add_packed_ref(struct ref_store *ref_store,
 		    const char *refname, const struct object_id *oid);
diff --git a/refs/packed-backend.c b/refs/packed-backend.c
index 6619052e96..eb9da04576 100644
--- a/refs/packed-backend.c
+++ b/refs/packed-backend.c
@@ -321,7 +321,7 @@ static struct ref_dir *get_packed_refs(struct packed_ref_store *refs)
 /*
  * Add or overwrite a reference in the in-memory packed reference
  * cache. This may only be called while the packed-refs file is locked
  * (see lock_packed_refs()). To actually write the packed-refs file,
  * call commit_packed_refs().
  */
 void add_packed_ref(struct ref_store *ref_store,
@@ -515,11 +515,11 @@ static int write_packed_entry(FILE *fh, const char *refname,
 	return 0;
 }
 
-int lock_packed_refs(struct ref_store *ref_store, int flags)
+int packed_refs_lock(struct ref_store *ref_store, int flags)
 {
 	struct packed_ref_store *refs =
 	        packed_downcast(ref_store, REF_STORE_WRITE | REF_STORE_MAIN,
-				"lock_packed_refs");
+				"packed_refs_lock");
 	static int timeout_configured = 0;
 	static int timeout_value = 1000;
 	struct packed_ref_cache *packed_ref_cache;
@@ -567,7 +567,7 @@ static const char PACKED_REFS_HEADER[] =
 /*
  * Write the current version of the packed refs cache from memory to
  * disk. The packed-refs file must already be locked for writing (see
  * lock_packed_refs()). Return zero on success. On errors, rollback
  * the lockfile, write an error message to `err`, and return a nonzero
  * value.
  */
@@ -698,7 +698,7 @@ int repack_without_refs(struct ref_store *ref_store,
 	if (!needs_repacking)
 		return 0; /* no refname exists in packed refs */
 
-	if (lock_packed_refs(&refs->base, 0)) {
+	if (packed_refs_lock(&refs->base, 0)) {
 		unable_to_lock_message(refs->path, errno, err);
 		return -1;
 	}
@@ -321,7 +321,7 @@ static struct ref_dir *get_packed_refs(struct packed_ref_store *refs)
  * Add or overwrite a reference in the in-memory packed reference
  * cache. This may only be called while the packed-refs file is locked
- * (see lock_packed_refs()). To actually write the packed-refs file,
+ * (see packed_refs_lock()). To actually write the packed-refs file,
  * call commit_packed_refs().
  */
@@ -567,7 +567,7 @@ static const char PACKED_REFS_HEADER[] =
  * Write the current version of the packed refs cache from memory to
  * disk. The packed-refs file must already be locked for writing (see
- * lock_packed_refs()). Return zero on success. On errors, rollback
+ * packed_refs_lock()). Return zero on success. On errors, rollback
  * the lockfile, write an error message to `err`, and return a nonzero
  * value.
-- 
2.11.0


  parent reply	other threads:[~2017-06-15 14:48 UTC|newest]

Thread overview: 52+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2017-06-15 14:47 [PATCH 00/28] Create a reference backend for packed refs Michael Haggerty
2017-06-15 14:47 ` [PATCH 01/28] add_packed_ref(): teach function to overwrite existing refs Michael Haggerty
2017-06-15 14:47 ` [PATCH 02/28] packed_ref_store: new struct Michael Haggerty
2017-06-15 14:47 ` [PATCH 03/28] packed_ref_store: move `packed_refs_path` here Michael Haggerty
2017-06-16  5:30   ` Stefan Beller
2017-06-15 14:47 ` [PATCH 04/28] packed_ref_store: move `packed_refs_lock` member here Michael Haggerty
2017-06-16  5:39   ` Stefan Beller
2017-06-16  6:43     ` Michael Haggerty
2017-06-16 15:44       ` Stefan Beller
2017-06-15 14:47 ` [PATCH 05/28] clear_packed_ref_cache(): take a `packed_ref_store *` parameter Michael Haggerty
2017-06-15 14:47 ` [PATCH 06/28] validate_packed_ref_cache(): " Michael Haggerty
2017-06-15 14:47 ` [PATCH 07/28] get_packed_ref_cache(): " Michael Haggerty
2017-06-15 14:47 ` [PATCH 08/28] get_packed_refs(): " Michael Haggerty
2017-06-15 14:47 ` [PATCH 09/28] add_packed_ref(): " Michael Haggerty
2017-06-15 14:47 ` [PATCH 10/28] lock_packed_refs(): " Michael Haggerty
2017-06-15 14:47 ` [PATCH 11/28] commit_packed_refs(): " Michael Haggerty
2017-06-15 14:47 ` [PATCH 12/28] rollback_packed_refs(): " Michael Haggerty
2017-06-15 14:47 ` [PATCH 13/28] get_packed_ref(): " Michael Haggerty
2017-06-15 14:47 ` [PATCH 14/28] repack_without_refs(): " Michael Haggerty
2017-06-15 14:47 ` [PATCH 15/28] packed_peel_ref(): new function, extracted from `files_peel_ref()` Michael Haggerty
2017-06-16  5:42   ` Stefan Beller
2017-06-16  6:46     ` Michael Haggerty
2017-06-16 15:47       ` Stefan Beller
2017-06-15 14:47 ` [PATCH 16/28] packed_ref_store: support iteration Michael Haggerty
2017-06-15 14:47 ` [PATCH 17/28] packed_read_raw_ref(): new function, replacing `resolve_packed_ref()` Michael Haggerty
2017-06-15 14:47 ` [PATCH 18/28] packed-backend: new module for handling packed references Michael Haggerty
2017-06-16  5:48   ` Stefan Beller
2017-06-15 14:47 ` [PATCH 19/28] packed_ref_store: make class into a subclass of `ref_store` Michael Haggerty
2017-06-15 14:47 ` [PATCH 20/28] commit_packed_refs(): report errors rather than dying Michael Haggerty
2017-06-15 14:47 ` [PATCH 21/28] commit_packed_refs(): use a staging file separate from the lockfile Michael Haggerty
2017-07-20 23:11   ` Junio C Hamano
2017-07-20 23:30     ` Jonathan Nieder
2017-07-21  6:01       ` Junio C Hamano
2017-07-21  7:14         ` Junio C Hamano
2017-07-24 16:59         ` Jeff King
2017-07-24 17:09           ` Jonathan Nieder
2017-07-24 17:10             ` Jeff King
2017-07-24 21:43               ` Junio C Hamano
2017-07-26 23:49                 ` Michael Haggerty
2017-06-15 14:47 ` Michael Haggerty [this message]
2017-06-15 14:47 ` [PATCH 23/28] packed_refs_lock(): report errors via a `struct strbuf *err` Michael Haggerty
2017-06-15 14:47 ` [PATCH 24/28] packed_refs_unlock(), packed_refs_is_locked(): new functions Michael Haggerty
2017-06-15 14:47 ` [PATCH 25/28] clear_packed_ref_cache(): don't protest if the lock is held Michael Haggerty
2017-06-15 14:47 ` [PATCH 26/28] commit_packed_refs(): remove call to `packed_refs_unlock()` Michael Haggerty
2017-06-15 14:47 ` [PATCH 27/28] repack_without_refs(): don't lock or unlock the packed refs Michael Haggerty
2017-06-15 14:47 ` [PATCH 28/28] read_packed_refs(): die if `packed-refs` contains bogus data Michael Haggerty
2017-06-19 18:51 ` [PATCH 00/28] Create a reference backend for packed refs Junio C Hamano
2017-06-19 19:25   ` Junio C Hamano
2017-06-19 19:43     ` Jeff King
2017-06-19 19:53       ` Jeff King
2017-06-22  7:36         ` Michael Haggerty
2017-06-22 15:33           ` Junio C Hamano

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

  List information: http://vger.kernel.org/majordomo-info.html

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=fdc991cfb05588fc93778a6ce3df197ac6c95146.1497534157.git.mhagger@alum.mit.edu \
    --to=mhagger@alum.mit.edu \
    --cc=avarab@gmail.com \
    --cc=bmwill@google.com \
    --cc=git@vger.kernel.org \
    --cc=gitster@pobox.com \
    --cc=novalis@novalis.org \
    --cc=pclouds@gmail.com \
    --cc=peff@peff.net \
    --cc=sbeller@google.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
Code repositories for project(s) associated with this public inbox

	https://80x24.org/mirrors/git.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).